# Porthmeus
# 17.05.18
source("~/scripts/RNAseq/RforRNAseq/misc/plottingColors.R")
require(flowCore)
require(extrafont)

load("Fig1c_data_MeanPerReplicate.RData")
load("Fig1c_data_SummarizedDatasets.RData")

# calculate the size calibration stuff and turn the values into micrometer
cal <- read.FCS("../SizeCalibration.fcs", alter.names=TRUE)
cal <- as.data.frame(exprs(cal))
dCal <- density(cal[,1])
q<-which(diff(sign(diff(dCal$y)))==-2)+1
maxima <- dCal$x[q][order(dCal$y[q],decreasing=T)][1:4]
size <- c(6, 10, 4, 15)
mod<- lm(size ~ maxima)
pdf("Fig1c_CellSize.pdf", width=2.5, height=4, family="Arial")
par(bty="n", mar=c(4,4,1,0))

# create a density plot
plot(0, type="n", ylim =c(0, 0.08), xlim =c(0,50), xlab=expression(paste("Cell diameter [",mu,"m]",sep="")), ylab="Density")
#abline(v=maxima, col="gray", lty=2)
i<-0
for(set in names(data)){
    i<-i+1
    x <- data[[set]][,1]
    x <- predict(mod, data.frame(maxima=x))
    points(density(x), col = temperatureColors[i], type="l", lwd=1.5)
}
legend("topleft", col=temperatureColors, lty=1, lwd=1.5, legend=paste(gsub("AEP","",names(data)), "°C"),bty="n", cex=0.8)


# create a boxplot of the mean cell sizes per sample
#require(beeswarm)
ylim <- c(min(dataMean[["MeanCellSize"]])*0.95 , max(dataMean[["MeanCellSize"]]*1.08))
boxplot(data=dataMean, MeanCellSize~Sample,pch=19, col=temperatureColors, ylab = expression(paste("Cell diameter [",mu,"m]",sep="")), xlab ="Rearing temperature [°C]", names=gsub("AEP","",levels(dataMean[["Sample"]])), 
    ylim=ylim, las=1)
#boxplot(data=dataMean, MeanCellSize~Sample, add=T, names=rep("",4))
max <- max(dataMean[["MeanCellSize"]])
points(c(1,2)+2,rep(max*1.02,2), type="l")
points(c(1,2)+1,rep(max*1.04,2), type="l")
points(c(1,2),rep(max*1.06,2), type="l")
text(c(1.5,2.5,3.5),rev(c(max*1.04,max*1.06,max*1.08)), "***", cex=1.5)


dev.off()
