# Porthmeus
# 17.05.18
source("~/scripts/RNAseq/RforRNAseq/misc/plottingColors.R")
require(flowCore)
require(extrafont)

load("Fig2c_data_MeanPerReplicate.RData")
load("Fig2c_data_SummarizedDatasets.RData")

# calculate the size calibration stuff and turn the values into micrometer
cal <- read.FCS("../SizeCalibration.fcs", alter.names=TRUE)
cal <- as.data.frame(exprs(cal))
dCal <- density(cal[,1])
q<-which(diff(sign(diff(dCal$y)))==-2)+1
maxima <- dCal$x[q][order(dCal$y[q],decreasing=T)][1:4]
size <- c(6, 10, 4, 15)
mod<- lm(size ~ maxima)

cols <- insrColors[c(2,1)]
ltps <- c(rep(1,4),rep(2,4))

pdf("Fig2c_plot_CellSizeBoxplot.pdf", width=3.5, height=4, pointsize=12, family="Arial")
par(bty="n",mar=c(4,4,3,0))
# create a plot of the mean values of the individual samples
dataMean[["Sample"]] <- factor(dataMean[["Sample"]], levels=c("ctrl_08°C","KD_08°C","ctrl_12°C","KD_12°C","ctrl_18°C","KD_18°C","ctrl_22°C","KD_22°C"))
dataMean <- droplevels(dataMean[grep("18|22",dataMean[["Sample"]]),])
require(beeswarm)


meanmin <- min(dataMean[["MeanCellSize"]])
ylim <- c(meanmin*0.94, max(dataMean[["MeanCellSize"]])*1.05)
boxplot(data=dataMean,
        MeanCellSize~Sample,
        col=insrColors,
        ylab= expression(paste("Cell diameter [",mu,"m]",sep="")),
        names=rep(c("ctrl","ecto/endo"),2),
        xlab="INSR-HP C1-1",
        ylim=ylim,cex=0.6,
        las=1)
text(c(1.5,3.5),rep(meanmin*0.97,2),c("18°C","22°C"))

meanmin <- meanmin*0.95
points(c(1,2),c(meanmin,meanmin), type="l") 
points(c(3,4),c(meanmin,meanmin), type="l") 

dev.off()
print(pairwise.wilcox.test(dataMean[["MeanCellSize"]], dataMean[["Sample"]], p.adjust.method="BH"))

