require("beeswarm")
require("extrafont")
require("data.table")


# read the data
df <- fread("Fig5_data_SizeInhibitors.csv")
df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000


# subset data and format
# LDN193189
ldn <- df[Inhibitor == "LDN193189" & Genotype == "AEP F2A4",]
ldn[["Concentration"]] <- as.factor(gsub("H2O","HM", as.character(ldn[["Concentration"]])))
ldn[["Concentration"]] <- factor(ldn[["Concentration"]], levels = levels(ldn[["Concentration"]])[c(5,1,2,4)])
ldn <- ldn[!is.na(Concentration),]

# K02288
k02 <- df[Inhibitor == "K02288" & Genotype == "AEP F2A4",]
k02[["Concentration"]] <- factor(k02[["Concentration"]] , levels = unique(k02[["Concentration"]])[c(2,1,3,4)])

# INSR-KD + K02288
INSR <- droplevels(df[grep("INSR",df[["Sample"]]),])
INSR[["T_HP"]] <- factor(paste(INSR[["Genotype"]], INSR[["Concentration"]], sep="_"), levels=c("ctrl_DMSO","ecto/endo_DMSO","ecto/endo_1µM"))

# INSR including ctrl animals treated with K02288
INSRall <- droplevels(df[grep("INSR",df[["Sample"]]),])
INSRall[["T_HP"]] <- factor(paste(INSR[["Genotype"]], INSR[["Concentration"]], sep="_"), levels=c("ctrl_DMSO","ecto/endo_DMSO","ctrl_1µM","ecto/endo_1µM"))

# FoxO + LDN-193189
FoxOecto <- df[Genotype %in% c("FoxO-HP ecto","FoxO-HP ctrl"),]  

FoxOecto[["Concentration"]] <- factor(FoxOecto[["Concentration"]], level = c("ctrl", "H2O", "3µM"))

FoxOectoendo <- df[Genotype %in% c("FoxO-HP ecto/endo","FoxO-HP ctrl"),]  
FoxOectoendo[["Concentration"]] <- factor(FoxOectoendo[["Concentration"]], level = c("ctrl", "H2O", "3µM"))


# plot the different plots
pdf("Fig5ab_plot_InhibitorSizes.pdf", family="Arial", width=4.5, height=4)
par(bty="n")

# LDN 193189
max <- max(ldn[["Epis_per_polyp"]])*1.2
boxplot(data= ldn, Epis_per_polyp ~ Concentration, xlab = "LDN-193189", ylab = "No. of epith. cells per polyp x1000", border="white", ylim = c(0, max), las = 1)
beeswarm(data = ldn, Epis_per_polyp ~ Concentration, add=T, col = paste("gray",rep(20,4)*4:1, sep=""), pch=19, xaxt="n", yaxt="n", method ="center")
boxplot(data= ldn, Epis_per_polyp ~ Concentration, add= T, xaxt="n", yaxt="n", outline = F)

# add statistics
print("LDN-193189")
print(pairwise.wilcox.test(ldn[,Epis_per_polyp], ldn[,Concentration], p.adjust.method = "BH"))

points(c(1,3),rep(max(ldn[["Epis_per_polyp"]])*1.05,2), type="l")
points(c(1,4),rep(max(ldn[["Epis_per_polyp"]])*1.15,2), type="l")
text(c(2,2.5),c(1.1,1.2)*max(ldn[["Epis_per_polyp"]]), c("*","***"), cex=1.5)



# K02288
max <- max(k02[["Epis_per_polyp"]])*1.3
boxplot(data= k02, Epis_per_polyp ~ Concentration, xlab = "K02288", ylab = "No. of epith. cells per polyp x1000", border="white", ylim = c(0, max), las = 1)
beeswarm(data = k02, Epis_per_polyp ~ Concentration, add=T, col = paste("gray",rep(20,4)*4:1, sep=""), pch=19, xaxt="n", yaxt="n", method="center")
boxplot(data= k02, Epis_per_polyp ~ Concentration, add= T, xaxt="n", yaxt="n", outline = F)

# add statistics
print("K02288")
print(pairwise.wilcox.test(k02[,Epis_per_polyp], k02[,Concentration], p.adjust.method = "BH"))

points(c(1,4),rep(max(k02[["Epis_per_polyp"]])*1.25,2), type="l")
points(c(1,3),rep(max(k02[["Epis_per_polyp"]])*1.15,2), type="l")
points(c(1,2),rep(max(k02[["Epis_per_polyp"]])*1.05,2), type="l")
text(c(1.5,2,2.5),c(1.1,1.2,1.3)*max(k02[["Epis_per_polyp"]]), c("***"), cex=1.5)

dev.off()



# plot the inhibitor treatment of KD animals
pdf("Fig5cde_plot_InhibitorSizesTG.pdf", family="Arial", width=3, height=4)
par(bty="n")


# INSR + K02288
max <- max(INSR[["Epis_per_polyp"]])*1.4
boxplot(data= INSR, Epis_per_polyp ~ T_HP,
    xlab = "K02288",
    ylab = "No. of epith. cells per polyp x1000",
    border="white",
    ylim = c(0, max),
    las = 1,
    main = "INSR-HP ecto/endo",
    names=c("ctrl","DMSO","1µM")
    )

beeswarm(data = INSR,
        Epis_per_polyp ~ T_HP,
        add=T,
        col=c("gray80", "#ccaa66ff","#9a8355ff"),
        pch=19,
        xaxt="n",
        yaxt="n")

boxplot(data= INSR,
    Epis_per_polyp ~ T_HP,
    add= T,
    xaxt="n",
    yaxt="n",
    outline = F)

# add statistics
print("INSR-TG with K02288")
print(pairwise.wilcox.test(INSR[,Epis_per_polyp], INSR[, T_HP], p.adjust.method="BH"))
mE <- max(INSR[,Epis_per_polyp])
points(c(1,2),rep(mE,2)*1.1,type="l")
points(c(1,3),rep(mE,2)*1.2,type="l")
points(c(2,3),rep(mE,2)*1.3,type="l")
text(c(1.5,2,2.5),c(mE)*c(1.15,1.25,1.35), c("*","***","***"),cex=1.5)



# FoxO-KD + LDN-193189
# FoxO-KD ecto
max <- max(FoxOecto[["Epis_per_polyp"]])*1.2

boxplot(data= FoxOecto, Epis_per_polyp ~ Concentration, xlab = "LDN-193189", ylab = "No. of epith. cells per polyp x1000", border="white", ylim = c(0, max), las = 1, main = "FoxO-HP ecto")
beeswarm(data = FoxOecto, Epis_per_polyp ~ Concentration, add=T, col = c("gray80", "#66cc66ff", "#589658ff"), pch=19, xaxt="n", yaxt="n")
boxplot(data= FoxOecto, Epis_per_polyp ~ Concentration, add= T, xaxt="n", yaxt="n", outline = F)

# add statistics
print("FoxOecto with LDN193189")
print(pairwise.wilcox.test(FoxOecto$Epis_per_polyp, FoxOecto$Concentration), p.adjust.method="BH")
points(c(1,2),rep(max(FoxOecto[["Epis_per_polyp"]])*1.05,2), type="l")
points(c(1,3),rep(max(FoxOecto[["Epis_per_polyp"]])*1.15,2), type="l")
points(c(2,3),rep(max(FoxOecto[["Epis_per_polyp"]])*0.95,2), type="l")
text(c(1.5,2,2.5),c(1.1,1.2,1)*max(FoxOecto[["Epis_per_polyp"]]), c("***","***","*"), cex=1.5)

# FoxO-KD ecto/endo
max <- max(FoxOectoendo[["Epis_per_polyp"]])*1.2

boxplot(data= FoxOectoendo, Epis_per_polyp ~ Concentration, xlab = "LDN-193189", ylab = "No. of epith. cells per polyp x1000", border="white", ylim = c(0, max), las = 1, main = "FoxO-HP ecto/endo")
beeswarm(data = FoxOectoendo, Epis_per_polyp ~ Concentration, add=T, col = c("gray80", "#ffb380ff", "#c28155ff"), pch=19, xaxt="n", yaxt="n")
boxplot(data= FoxOectoendo, Epis_per_polyp ~ Concentration, add= T, xaxt="n", yaxt="n", outline = F)

# add statistics
print("FoxOectoendo with LDN193189")
print(pairwise.wilcox.test(FoxOectoendo$Epis_per_polyp, FoxOectoendo$Concentration, p.adjust.method="BH"))
points(c(1,2),rep(max(FoxOectoendo[["Epis_per_polyp"]])*1.05,2), type="l")
points(c(1,3),rep(max(FoxOecto[["Epis_per_polyp"]])*1.15,2), type="l")
points(c(2,3),rep(max(FoxOecto[["Epis_per_polyp"]])*0.95,2), type="l")
text(c(1.5,2,2.5),c(1.1,1.2,1)*max(FoxOecto[["Epis_per_polyp"]]), c("***","***","**"), cex=1.5)

dev.off()




