# Porthmeus
# 02.11.18
require(data.table)
require(extrafont)
require(beeswarm)

df <- fread("Fig5_data_SizeInhibitors.csv")
df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000

# subset data and format
# INSR including ctrl animals treated with K02288
INSRall <- droplevels(df[grep("INSR",df[["Sample"]]),])
INSRall[["T_HP"]] <- factor(paste(INSRall[["Genotype"]], INSRall[["Concentration"]], sep="_"), levels=c("ctrl_DMSO","ecto/endo_DMSO","ctrl_1µM","ecto/endo_1µM"))


# plot
pdf("SupFig12_plot_INSRK02288.pdf", width=4, height=4, family="Arial")
par(bty="n")
mE <- max(INSRall[["Epis_per_polyp"]])
boxplot(data=INSRall, Epis_per_polyp~T_HP, ylim=c(0,mE*1.5), las=1,
    names=c("ctrl","INSR-KD","ctrl","INSR-KD"),
    ylab="No. of epth. cells per polyp x1000", main="INSR-KD ecto/endo", border=NA)
beeswarm(data=INSRall, Epis_per_polyp~T_HP, pch=19, add=T, col=c("gray80", "#ccaa66ff","gray40","#9a8355ff"))
boxplot(data=INSRall, Epis_per_polyp~T_HP, add=T, las=1,
    names=c("ctrl","INSR-KD","ctrl","INSR-KD")
    )

points(c(1,2),c(0,0), type="l")
points(c(3,4),c(0,0), type="l")
text(c(1.5,3.5), c(1,1), c("DMSO","K02288"))
print(pairwise.wilcox.test(INSRall[["Epis_per_polyp"]], INSRall[["T_HP"]], p.adjust.method="BH"))
points(c(1,2),rep(mE,2)*1.1,type="l")
points(c(3,4),rep(mE,2),type="l")
points(c(1,3),rep(mE,2)*1.2,type="l")
points(c(2,3),rep(mE,2)*1.3,type="l")
points(c(2,4),rep(mE,2)*1.4,type="l")
text(c(1.5,2,2.5,3),c(mE)*c(1.15,1.25,1.35,1.45), c("*","***","***","***"),cex=1.5)
text(c(3.5),mE*1.05, "ns")
dev.off()
