require("beeswarm")
require("extrafont")
require("data.table")



df <- fread("Fig6bc_data_InhibitorBudding.csv")
ldn <- df[Treatment == "LDN-193189",]
ldn[["Concentration"]] <- factor(ldn[["Concentration"]], level = c("HM", "3µM"))
k02 <-  df[Treatment == "K02288",]
k02[["Concentration"]] <- factor(k02[["Concentration"]], level = c("DMSO", "1µM"))


pdf("Fig6bc_plot_InhibitorBudding.pdf", family="Arial", width=3, height=4)
par(bty="n")

# LDN-193189
max <- max(ldn[["time2bud"]])*1.1
boxplot(data= ldn, time2bud ~ Concentration, xlab = "LDN-193189", ylab = expression(Delta*T[1]), border="white", ylim = c(0, max), las = 1)
beeswarm(data = ldn, time2bud ~ Concentration, add=T, col = paste("gray",rep(20,4)*c(4,1), sep=""), pch=19, xaxt="n", yaxt="n", method ="center", corral="random")
means <- tapply((ldn[["time2bud"]]),(ldn[["Concentration"]]),mean)

segments(0.6,means[[1]],1.4,means[[1]], lwd = 2, lty = 1, col = "black")
segments(1.6,means[[2]],2.4,means[[2]], lwd = 2, lty = 1, col = "black")

# add statistics
print(wilcox.test(ldn[,time2bud]~ldn[,Concentration]))
points(c(1,2),rep(max(ldn[["time2bud"]])*1.05,2), type="l")
text(c(1.5),c(1.1)*max(ldn[["time2bud"]]), c("***"), cex=1.5)

# K02288
max <- max(ldn[["time2bud"]])*1.1
boxplot(data= k02, time2bud ~ Concentration, xlab = "K02288", ylab =  expression(Delta*T[1]) , border="white", ylim = c(0, max), las = 1)
beeswarm(data = k02, time2bud ~ Concentration, add=T, col = paste("gray",rep(20,4)*c(4,2), sep=""), pch=19, xaxt="n", yaxt="n", method ="center", corral="random")
means <- tapply((k02[["time2bud"]]),(k02[["Concentration"]]),mean)

segments(0.6,means[[1]],1.4,means[[1]], lwd = 2, lty = 1, col = "black")
segments(1.6,means[[2]],2.4,means[[2]], lwd = 2, lty = 1, col = "black")

# add statistics
print(wilcox.test(k02[,time2bud]~k02[,Concentration]))
points(c(1,2),rep(max(ldn[["time2bud"]])*1.05,2), type="l")
text(c(1.5),c(1.1)*max(ldn[["time2bud"]]), c("***"), cex=1.5)

dev.off()
