# Porthmeus
# 06.06.18



require(limma)
require(flowCore)
require(extrafont)

load("SupFig13_data_SummarizedDatasets.RData")


# calculate the size calibration stuff and turn the values into micrometer
cal <- read.FCS("../SizeCalibration.fcs", alter.names=TRUE)
cal <- as.data.frame(exprs(cal))
dCal <- density(cal[,1])
q<-which(diff(sign(diff(dCal$y)))==-2)+1
maxima <- dCal$x[q][order(dCal$y[q],decreasing=T)][1:4]
size <- c(6, 10, 4, 15)
mod<- lm(size ~ maxima)

dataSel <- list("AEP_K02288" =grep("AEP_F2A4_K02288", names(data), value=T),
                "AEP_LDN193189" = grep("AEP_F2A4_LDN193189", names(data), value=T),
                "INSR_K02288" = grep("INSR-HP_TG_K02288",names(data), value=T),
                "FoxO_LDN193189" = grep("FoxO", names(data), value=T))

cols <- colorRampPalette(c("gray20","gray80"))

pdf("SupFig13extra_plot_densityPlots.pdf")
for(con in names(dataSel)){
    col <- cols(length(dataSel[[con]]))
    plot(0, type="n", ylim =c(0, 0.1), xlim =c(0,50), xlab=expression(paste("Cell diameter [",mu,"m]",sep="")), ylab="Density",main=con)
    i <- 0
    for(set in dataSel[[con]]){
    i<-i+1
    x <- data[[set]][,1]
    x <- predict(mod, data.frame(maxima=x))
    points(density(x), col = col[i], type="l", lwd=1.5)
    }
legend("topleft", col=cols(i), lty=1, lwd=1.5, legend=dataSel[[con]],bty="n", cex=0.8)
}
dev.off()

load("SupFig13_data_MeanPerReplicate.RData")
dataMean[[2]] <- gsub("-HP","-KD",dataMean[[2]])
dataMean <- droplevels(dataMean[-1*grep("4µM", dataMean[[4]]),])
dataMean[[4]] <- gsub("µ","u", dataMean[[4]])
dataMean[[4]] <- factor(gsub("H20","H2O",dataMean[[4]]), levels=c("DMSO","H2O","0.5uM", "1uM", "2uM", "3uM", "4uM"))
cols <- colorRampPalette(c("gray80","gray20"))

pdf("SupFig13_data_CellSizeInhbitors.pdf", width=4, height=4, family="Arial")
par(bty="n")
for(line in unique(dataMean[,2])){
    for(inhb in unique(dataMean[,3])){
        
        sel <- dataMean[,2] == line & dataMean[,3] ==inhb
        if(all(!sel)==F){
            dataTmp <- droplevels(dataMean[sel,])

            boxplot(data=dataTmp, MeanCellSize~V4, col=cols(length(unique(dataTmp[[4]]))), main=paste(line, inhb), ylab=expression(paste("Cell diameter [",mu,"m]",sep="")))
            print(paste(line, inhb))
            print(pairwise.wilcox.test(dataTmp$MeanCellSize, dataTmp$V4, p.adjust.method = "BH"))
        }
    }
}


dev.off()
