require(beeswarm)
require(extrafont)
require(data.table)


dfAll <- fread("SupFig5bd_data_MaxSizeINSRFoxOTemp.csv")
cols <- c("#ccccc0","#ccaa66")

# subset to INSR temperature

df <- dfAll[Genotype == "INSR-HP C1-1",]
df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000
df[["total_per_polyp"]] <- df[["total_per_polyp"]]/1000
df[["CellLine"]] <- factor(gsub("empty","ctrl",df[["CellLine"]]), level=c("ctrl","ecto/endo"))
df[["Sample"]] <- factor(df[["Sample"]], level =c("INSR C1-1 empty 8°C","INSR C1-1 ecto/endo 8°C","INSR C1-1 empty 12°C","INSR C1-1 ecto/endo 12°C","INSR C1-1 empty 18°C","INSR C1-1 ecto/endo 18°C","INSR C1-1 empty 22°C","INSR C1-1 ecto/endo 22°C"))


# plot INSR temperature
min <- 0

pdf("SupFig5bd_plot_MaxSizeINSRFoxOTemp.pdf", family="Arial", width=7,height=4)


par(bty="n",mar=c(4,4,3,0))
selection <- "Epis_per_polyp"
max <- max(df[[selection]])*1.2
boxplot(data = df, Epis_per_polyp ~ Sample, names= rep(levels(df[["CellLine"]]),4),ylim =c(min, max), border="white", ylab= "No. of epith. cells per polyp x1000", las=1, xlab = "INSR-HP C1-1")
beeswarm(data = df, Epis_per_polyp ~ Sample, add = T, col = cols, pch = 19, xaxt = 'n', yaxt = 'n',cex=1)
boxplot(data = df, Epis_per_polyp ~ Sample,add = T, xaxt = 'n', yaxt = 'n',outline = F, lwd=1.5)


# add statistics
print(pairwise.wilcox.test(df[[selection]], df[["Sample"]], p.adjust.method="fdr"))

points(c(1,2), rep(0,2), type = "l", cex=1.5)
points(c(3,4), rep(0,2), type = "l", cex=1.5)
points(c(1,2)+4, rep(0,2), type = "l", cex=1.5)
points(c(1,2)+6, rep(0,2), type = "l", cex=1.5)
text((x=(1:4)*2)-0.5, y=1.1, label = c("8°C","12°C","18°C","22°C"))
points(c(1,2)+4, rep(max(df[[selection]])*1.05,2), type = "l")
points(c(1,2)+6, rep(max(df[[selection]])*1.05,2), type = "l")
points(c(1,2), rep(max(df[[selection]])*1.05,2), type = "l")
points(c(1,2)+2, rep(max(df[[selection]])*1.05,2), type = "l")
text(c(5.5,7.5), rep(max(df[[selection]])*1.1,2), "*", cex=1.5)
text(c(1.5,3.5),rep(max(df[[selection]])*1.1,2), "ns")


# subset data to FoxO
cols <- c("#cccccc","#FF8080","#66CC66","#ffb380")
df <- dfAll[Genotype == "FoxO-HP D11a",]

df[["Epis_per_polyp"]] <- df[["Epis_per_polyp"]]/1000
df[["total_per_polyp"]] <- df[["total_per_polyp"]]/1000
df[["CellLine"]] <- factor(gsub("empty","ctrl",df[["CellLine"]]), level=c("ctrl","endo","ecto","ecto/endo"))
df[["Sample"]] <- factor(df[["Sample"]], level =c("FoxO-HP D11a empty 12°C","FoxO-HP D11a endo 12°C","FoxO-HP D11a ecto 12°C","FoxO-HP D11a ecto/endo 12°C","FoxO-HP D11a empty 18°C","FoxO-HP D11a endo 18°C","FoxO-HP D11a ecto 18°C","FoxO-HP D11a ecto/endo 18°C"))

# plot FoxO-KD temperature
max <- max(df[[selection]])*1.4
boxplot(data = df, Epis_per_polyp ~ Sample, names= rep(levels(df[["CellLine"]]),2),ylim =c(min, max), border="white", ylab= "No. of epith. cells per polyp x1000", las=1, xlab = "FoxO-HP D11a")
beeswarm(data = df, Epis_per_polyp ~ Sample, add = T, col = cols, pch = 19, xaxt = 'n', yaxt = 'n',cex=1)
boxplot(data = df, Epis_per_polyp ~ Sample,add = T, xaxt = 'n', yaxt = 'n',outline = F, lwd=1.5)

# add statistics
print(pairwise.wilcox.test(df[[selection]], df[["Sample"]], p.adjust.method="fdr"))


liney <- max(df[[selection]])
points(c(1,3), rep(liney,2)*1.05, type='l', cex=1.5)
points(c(1.85,2,2.15),rep(liney,3)*1.1, pch="*", cex=1.5)
points(c(1,4), rep(liney,2)*1.15, type='l', cex=1.5)
points(c(2.35,2.5,2.65),rep(liney,3)*1.2, pch="*", cex=1.5)

points(c(1,3)+4, rep(liney,2)*1.05, type='l', cex=1.5)
points(c(1.85,2,2.15)+4,rep(liney,3)*1.1, pch="*", cex=1.5)
points(c(1,4)+4, rep(liney,2)*1.15, type='l', cex=1.5)
points(c(2.35,2.5,2.65)+4,rep(liney,3)*1.2, pch="*", cex=1.5)

points(c(1,4), rep(0,2), type='l', cex=1.5)
points(c(1,4)+4, rep(0,2), type='l', cex=1.5)
text(x=c(2.5,6.5),y=1.2, label = c("12°C","18°C"))
dev.off()

