# Porthmeus
# 01.11.17

require(extrafont)
df <- read.csv("SupFig10a_data_qRTPCR.csv")
df[["Treatment"]] <- factor(df[["Treatment"]], levels = c("DMSO","1µM","5µM"))


vals <- matrix(0,nrow = 2, ncol = length(levels(df[["Gene"]])), dimnames = list(x=c("1µM","5µM"), y=levels(df[["Gene"]])))
sem <- matrix(0,nrow = 2, ncol = length(levels(df[["Gene"]])), dimnames = list(x=c("1µM","5µM"), y=levels(df[["Gene"]])))
stars <-c()
for(gene in levels(df[["Gene"]])){
    
    wDF <- droplevels(df[df[["Gene"]]==gene,])
    for(treatment in levels(wDF[["Treatment"]])){
        if(treatment != "DMSO"){
            vals[treatment,gene] <- log2(mean(wDF[wDF[["Treatment"]]== treatment,"FC"]))
            sem[treatment,gene] <- sd(log2(wDF[wDF[["Treatment"]]== treatment,"FC"]))/sqrt(length(grep(treatment, df[["Treatment"]])))
            if(treatment=="DMSO"){
                stars <- c(stars,"")
            } else {
                pval <- t.test(wDF[wDF[["Treatment"]]== treatment, "dCT"], wDF[wDF[["Treatment"]]=="DMSO","dCT"])
                if(pval[["p.value"]] < 0.001/2){
                    stars <- c(stars,"***")
                } else if( pval[["p.value"]] < 0.01/2){
                    stars <- c(stars,"**")
                } else if( pval[["p.value"]] < 0.05/2){
                    stars <- c(stars,"*")
                } else {
                    stars <- c(stars, "")
                }
            }
        }
    }
}
pdf("SupFig10a_plot_qRTresults.pdf", width = 5, height=4, family="Arial")
barplot(vals, beside =T, legend.text = T, ylim = c(min(vals),max(vals))*1.3, ylab = expression("log"[2]*"-fold-change"), args.legend=list(x="topleft", cex=0.8,bty="n",legend=paste(rownames(vals),"ALP")), col=c("gray90","gray60"), names.arg = c(colnames(vals)[-5], expression("TGF-"*beta*"2")))
abline(h=0)
xvals <- c(1,2,4,5,7,8,10,11,13,14)+0.5
i <- 0
semp <- as.vector(sem)
valsp <- as.vector(vals)
for(x in xvals){
    i <- i+1
    points(x=c(x,x),y=c(valsp[i]-semp[i],valsp[i]+semp[i]), type="l")
    points(x=c(x,x),y=c(valsp[i]-semp[i],valsp[i]+semp[i]), pch = 190, font = 5)
}
text(x=xvals, y=valsp-(max(vals)*0.4), stars, cex=1.2)
dev.off()
svg("SupFig10a_plot_qRTresults.svg", width = 6, height=4, family="Times")
barplot(vals, beside =T, legend.text = T, ylim = c(min(vals),max(vals))*1.3, ylab = expression("log"[2]*"-fold-change"), args.legend=list(x="topleft", cex=0.8,bty="n",legend=paste(rownames(vals),"ALP")), col=c("gray90","gray60"), names.arg = c(colnames(vals)[-5], expression("TGF-"*beta*"2")))
abline(h=0)
xvals <- c(1,2,4,5,7,8,10,11,13,14)+0.5
i <- 0
semp <- as.vector(sem)
valsp <- as.vector(vals)
for(x in xvals){
    i <- i+1
    points(x=c(x,x),y=c(valsp[i]-semp[i],valsp[i]+semp[i]), type="l")
    points(x=c(x,x),y=c(valsp[i]-semp[i],valsp[i]+semp[i]), pch = 190, font = 5)
}
text(x=xvals, y=valsp-(max(vals)*0.4), stars, cex=1.2)
dev.off()
