# Porthmeus
# 18.12.17

require(extrafont)

# get the data
df_all <- read.csv("SupFig10b_data_MaxSizeVsTentaclesMeans.csv",sep=",")
df_FoxO <- df_all[grep("D11a",df_all[["Line"]]),]
df_AEP <- df_all[grep("F2A4", df_all[["Line"]]),]
df_INSR <- df_all[grep("INSR",df_all[["Line"]]),]
df_plus <- df_all[grep("EH9|E11", df_all[["Line"]]),]

# define the colors
cls_FoxO <- c("gray40","#FF8080","#66CC66","#ffb380")
cls_AEP <- c("#a7aae8","#e8a8dd","#e8a8a8")
cls_INSR <- c("#ccccc0","#ccaa66")
cls_plus <- c("#e8a8dd","gray40","#66CC66")


# get the limits of the plotting area
ymin <- min(df_all[["TentaclesPerEpis"]])*0.94*0
ymax <- max(df_all[["TentaclesPerEpis"]])*1.1
xmin <- min(df_all[["MaxSizeMean"]])*0.7
xmax <- max(df_all[["MaxSizeMean"]])*1.2

# calc the regression and the confidence
m <- lm(TentaclesPerEpis ~ MaxSizeMean, data=df_all)
newx <- seq(xmin*0.9, xmax*1.1, length.out=100)
newx2 <- c(seq(xmin*0.9, xmax*1.1, length.out=100),seq(xmax*1.1, xmin*0.9, length.out=100))
preds <- predict(m, newdata = data.frame(MaxSizeMean=newx), interval="confidence")

#plot
pdf("SupFig10b_plot_ALPCorrelation.pdf", height=4, width = 5, family="Arial")


# get the limits of the plotting area
ymin <- min(df_all[["TentaclesPerEpis"]])*0.94*0
ymax <- max(df_all[["TentaclesPerEpis"]])*1.1
xmin <- min(df_all[["MaxSizeMean"]])*0.7
xmax <- max(df_all[["MaxSizeMean"]])*1.2

plot(data = df_all, TentaclesPerEpis ~MaxSizeMean, type="n",ylab = "Tentacles per 1000 epith. cells", xlab = "Maximum size in no. of epith. cells per polyp",ylim=c(ymin,ymax),xlim = c(xmin, xmax), bty="n")

poly <- c(preds[,2],sort(preds[,3],decreasing=F))

polygon(newx2,poly,col=adjustcolor("black",alpha.f=0.02), border=F)

abline(m, lty=1, col=adjustcolor("red", alpha.f=0.95))

lines(newx, preds[,3], lty= 2, col=adjustcolor("black", alpha.f=0.1))
lines(newx, preds[,2], lty= 2, col=adjustcolor("black", alpha.f=0.1))

for(i in 1:nrow(df_all)){
  Tvals <- c(df_all[i,"TentaclesPerEpis"]-df_all[i,"StdErrTentaclesPerEpis"],df_all[i,"TentaclesPerEpis"]+df_all[i,"StdErrTentaclesPerEpis"])
  Svals <- c(df_all[i,"MaxSizeMean"]-df_all[i,"StdErrMaxSizeMean"],df_all[i,"MaxSizeMean"]+df_all[i,"StdErrMaxSizeMean"])
  points(rep(df_all[i, "MaxSizeMean"],2),Tvals, pch = 190, font=5, cex=0.5)
  points(rep(df_all[i, "MaxSizeMean"],2),Tvals, type = "l",lwd=0.5)
  points(Svals,rep(df_all[i, "TentaclesPerEpis"],2), pch = 189, font=5, cex=0.5)
  points(Svals,rep(df_all[i, "TentaclesPerEpis"],2), type = "l",lwd=0.5)
}

points(data=df_FoxO, TentaclesPerEpis ~MaxSizeMean, bg = "gray35", pch = 21)
points(data=df_AEP, TentaclesPerEpis ~MaxSizeMean, bg = "gray35", pch = 24)
points(data=df_INSR, TentaclesPerEpis ~MaxSizeMean, bg = "gray35", pch = 22)
points(data=df_plus, TentaclesPerEpis ~MaxSizeMean, bg = "gray35", pch = 23)
points(data=df_all[c(13,14),] , TentaclesPerEpis ~MaxSizeMean, bg = c("yellow","deeppink2"), pch = 24)
points(data=df_all[c(15,16),], TentaclesPerEpis ~ MaxSizeMean, bg = c("green3","lightskyblue"),pch=24)

text(max(df_all[["MaxSizeMean"]]),max(df_all[["TentaclesPerEpis"]])*0.97,paste("R² = ", round(summary(m)$adj.r.squared, digits=2), "\np = ", round(anova(m)[["Pr(>F)"]][1], digits=6),sep=''), pos=4, offset=-3)

dev.off()
