# Porthmeus
# 18.12.18

require(dplyr)
require(ggplot2)
require(extrafont)

lmp <- function (modelobject) {
    if (class(modelobject) != "lm") stop("Not an object of class 'lm' ")
    f <- summary(modelobject)$fstatistic
    p <- pf(f[1],f[2],f[3],lower.tail=F)
    attributes(p) <- NULL
    return(p)
}

# load data and edit a little
size <- read.csv("SupFig9_10b_data_MaxSize.csv")
tentacle <- read.csv("SupFig9_10b_data_Tentacles.csv")
size[["Epis_per_polyp"]] <- size[["Epis_per_polyp"]]/1000
tentacle[["Epis"]] <- tentacle[["Epis"]]/1000

# define colors and sort the conditions
cols <- c("#e8a8dd","#e8a8dd","#a7aae8","#e8a8a8","green3","yellow","lightskyblue","deeppink2","gray40","#66CC66","#ffb380","#FF8080","gray40","#66CC66","#ccccc0","#ccaa66")
cols2 <- data.frame(Line=levels(tentacle[["Line"]]),cols=cols)
names(cols) <- cols2[[1]]
colScale <- scale_colour_manual(name ="Line", values = cols)
tentacle[["Line"]] <- factor(tentacle[["Line"]], levels=c("AEP F2A4 12°C", "AEP F2A4","AEP F2A4 22°C", "AEP EH9","INSR-HP C1-1 ctrl", "INSR-HP C1-1 ecto/endo","FoxO-HP E11 ctrl","FoxO-HP E11 ecto", "FoxO-HP D11a ctrl", "FoxO-HP D11a endo","FoxO-HP D11a ecto","FoxO-HP D11a ecto/endo", "AEP F2A4 K02288 DMSO","AEP F2A4 K02288 1µM","AEP F2A4 LDN-193189 ctrl","AEP F2A4 LDN-193189 3µM"))
size[["Sample"]] <- factor(size[["Sample"]], levels=c("AEP F2A4 12°C", "AEP F2A4","AEP F2A4 22°C", "AEP EH9","INSR-HP C1-1 ctrl", "INSR-HP C1-1 ecto/endo","FoxO-HP E11 ctrl","FoxO-HP E11 ecto", "FoxO-HP D11a ctrl", "FoxO-HP D11a endo","FoxO-HP D11a ecto","FoxO-HP D11a ecto/endo", "AEP F2A4 K02288 DMSO","AEP F2A4 K02288 1µM","AEP F2A4 LDN-193189 ctrl","AEP F2A4 LDN-193189 3µM"))

ord <- levels(tentacle[["Line"]])

# create boxplots of the individual factors
pdf("SupFig9abc_plot_SplitFig4.pdf", width=3.5, height=3, font="Arial")
par(bty="n", mar =c(5,5,2,0.5))
boxplot(data=size, Epis_per_polyp~Sample, las=2, col=cols[ord], main="Maximum size",ylab="No. of epith. cell\nper polyp x1000")
boxplot(data=tentacle, Tentacles~Line, las=2, col=cols[ord],ylab="No. of tentacles per polyp", main="Tentacles")
boxplot(data=tentacle, Epis~Line, las=2, col=cols[ord],ylab="No. of epith. cell\nper polyp x1000", main="Individual size") 
dev.off()

pp <- ggplot(data=tentacle, aes(y=Tentacles, x=Epis)) + 
        geom_smooth(method='lm', color="red", fill="gray80", size=0.5)+
        geom_point(aes(color=Line)) + 
        facet_wrap(~Line) +
        ylab("No. of ectopic tentacles") +
        xlab("No. of epith. cell per polyp x1000")+
        colScale

pvals <- c()
for(l in levels(tentacle$Line)){
    t <- droplevels(tentacle[tentacle[["Line"]] == l,])
    pvals <- c(pvals,lmp(lm(t$Epis ~ t$Tentacles)))
}
pvals <- data.frame(Line=levels(tentacle[["Line"]]), pvals=pvals, padj=p.adjust(pvals, method="BH"))

pp <- pp + annotate("text", y=53, x=13, label=paste("p =",formatC(pvals[["pvals"]], format = "e", digits = 2))) +
    theme_linedraw()+
    theme(legend.position = "none",
            panel.grid.major = element_blank(), 
            panel.grid.minor = element_blank(),
            strip.text.x = element_text(size = 8))
pdf("SupFig9g_plot_SplitFig4Extra.pdf", width=7, height=4, font="Arial")
print(pp)
dev.off()

# plot correlation of Tentacles to max size
sumTent <- tentacle %>% group_by(Line) %>% summarize(tentacles=mean(Tentacles), stdErrTent = sd(Tentacles)/sqrt(n()), curSize = mean(Epis), stdErrCurSize= sd(Epis)/sqrt(n()))
sumSize <- size %>% group_by(Sample) %>% summarize(size=mean(Epis_per_polyp), stdErrSize = sd(Epis_per_polyp)/sqrt(n()))
sumTentSize <-merge(sumSize, sumTent, by.x="Sample",by.y="Line")

# add colors and shapes to the data frame
sumTentSize[["cols"]] <- cols
shapes <- c("EH9"=23, "AEPtemp"=rep(24,3),"AEPInh"=rep(24,4), "D11a"=rep(21, 4), "E11"=rep(23,2), "INSR"=rep(22,2))
sumTentSize[["shape"]] <- shapes

sumTentSize2 <- sumTentSize[c(-5, -6, -7, -8), ]

pdf("SupFig9def_plot_TentacleSizeCorrelation.pdf", height=3, width=4, family="Arial")
par(bty="n")


# plot tentacles vs size
ymin <- 0
ymax <- max(sumTentSize2[["tentacles"]])*1.1
xmin <- min(sumTentSize2[["size"]])*0.7
xmax <- max(sumTentSize2[["size"]]) *1.2

# generate the linear model and plot the regression line/confidence interval
m <- lm(data=sumTentSize2, tentacles~size)
print(summary(m))

newx <- seq(xmin*0.9, xmax*1.1, length.out=100)
newx2 <- c(seq(xmin*0.9, xmax*1.1, length.out=100),seq(xmax*1.1, xmin*0.9, length.out=100))
preds <- predict(m, newdata = data.frame(size=newx), interval="confidence")


plot(data=sumTentSize2, tentacles~size, type="n",ylab = "Tentacles per 1000 epith. cells", xlab = "Maximum size in no. of epith.\ncells per polyp x1000",ylim=c(ymin,ymax),xlim = c(xmin, xmax))

# plot the confidence interval and the regression line of the linear model
poly <- c(preds[,2],rev(preds[,3]))
polygon(newx2,poly,col=adjustcolor("black",alpha.f=0.02), border=F)
abline(m, lty=1, col=adjustcolor("red", alpha.f=0.95))
lines(newx, preds[,3], lty= 2, col=adjustcolor("black", alpha.f=0.1))
lines(newx, preds[,2], lty= 2, col=adjustcolor("black", alpha.f=0.1))

# plot the std-dev of the size and tentacle values
for(i in 1:nrow(sumTentSize2)){
    Tvals <- c(sumTentSize2[i,"tentacles"] - sumTentSize2[i, "stdErrTent"],
                sumTentSize2[i,"tentacles"] + sumTentSize2[i, "stdErrTent"])
    Svals <- c(sumTentSize2[i,"size"] - sumTentSize2[i, "stdErrSize"],
                sumTentSize2[i,"size"] + sumTentSize2[i, "stdErrSize"])
    points(rep(sumTentSize2[i, "size"],2),Tvals, pch = 190, font=5, cex=0.5)
    points(rep(sumTentSize2[i, "size"],2),Tvals, type = "l",lwd=0.5)
    points(Svals,rep(sumTentSize2[i, "tentacles"],2), pch = 189, font=5, cex=0.5)
    points(Svals,rep(sumTentSize2[i, "tentacles"],2), type = "l",lwd=0.5)
}


# plot the actual points and the statistics
points(data=sumTentSize2, tentacles~size, bg=sumTentSize2[["cols"]], pch=sumTentSize2[["shape"]])
text(max(sumTentSize2[["size"]]),max(sumTentSize2[["tentacles"]])*0.97,paste("R² = ", round(summary(m)$adj.r.squared, digits=2), "\np = ", round(anova(m)[["Pr(>F)"]][1], digits=6),sep=''), pos=4, offset=-1.5)


# plot curSize vs size
ymin <- 0
ymax <- max(sumTentSize2[["curSize"]])*1.1
xmin <- min(sumTentSize2[["size"]])*0.7
xmax <- max(sumTentSize2[["size"]]) *1.2

# generate the linear model and plot the regression line/confidence interval
m <- lm(data=sumTentSize2, curSize~size)
print(summary(m))

newx <- seq(xmin*0.9, xmax*1.1, length.out=100)
newx2 <- c(seq(xmin*0.9, xmax*1.1, length.out=100),seq(xmax*1.1, xmin*0.9, length.out=100))
preds <- predict(m, newdata = data.frame(size=newx), interval="confidence")


plot(data=sumTentSize2, curSize~size, type="n",ylab = "Current size in no. of epith.\ncells per polyp x1000", xlab = "Maximum size in no. of epith.\ncells per polyp x1000",ylim=c(ymin,ymax),xlim = c(xmin, xmax))

# plot the confidence interval and the regression line of the linear model
poly <- c(preds[,2],rev(preds[,3]))
polygon(newx2,poly,col=adjustcolor("black",alpha.f=0.02), border=F)
abline(m, lty=1, col=adjustcolor("red", alpha.f=0.95))
lines(newx, preds[,3], lty= 2, col=adjustcolor("black", alpha.f=0.1))
lines(newx, preds[,2], lty= 2, col=adjustcolor("black", alpha.f=0.1))

# plot the std-dev of the size and tentacle values
for(i in 1:nrow(sumTentSize2)){
    Tvals <- c(sumTentSize2[i,"curSize"] - sumTentSize2[i, "stdErrCurSize"],
                sumTentSize2[i,"curSize"] + sumTentSize2[i, "stdErrCurSize"])
    Svals <- c(sumTentSize2[i,"size"] - sumTentSize2[i, "stdErrSize"],
                sumTentSize2[i,"size"] + sumTentSize2[i, "stdErrSize"])
    points(rep(sumTentSize2[i, "size"],2),Tvals, pch = 190, font=5, cex=0.5)
    points(rep(sumTentSize2[i, "size"],2),Tvals, type = "l",lwd=0.5)
    points(Svals,rep(sumTentSize2[i, "curSize"],2), pch = 189, font=5, cex=0.5)
    points(Svals,rep(sumTentSize2[i, "curSize"],2), type = "l",lwd=0.5)
}


# plot the actual points and the statistics
points(data=sumTentSize2, curSize~size, bg=sumTentSize2[["cols"]], pch=sumTentSize2[["shape"]])
text(min(sumTentSize2[["size"]]),max(sumTentSize2[["curSize"]])*0.97,paste("R² = ", round(summary(m)$adj.r.squared, digits=2), "\np = ", round(anova(m)[["Pr(>F)"]][1], digits=6),sep=''), pos=4, offset=-1.5)

# plot tentacles vs curSize
ymin <- 0
ymax <- max(sumTentSize2[["tentacles"]])*1.1
xmin <- min(sumTentSize2[["curSize"]])*0.7
xmax <- max(sumTentSize2[["curSize"]]) *1.2

# generate the linear model and plot the regression line/confidence interval
m <- lm(data=sumTentSize2, tentacles~curSize)
print(summary(m))

newx <- seq(xmin*0.9, xmax*1.1, length.out=100)
newx2 <- c(seq(xmin*0.9, xmax*1.1, length.out=100),seq(xmax*1.1, xmin*0.9, length.out=100))
preds <- predict(m, newdata = data.frame(curSize=newx), interval="confidence")


plot(data=sumTentSize2, tentacles~curSize, type="n",ylab = "Tentacles per 1000 epith. cells", xlab = "Current size in no. of epith.\ncells per polyp x1000",ylim=c(ymin,ymax),xlim = c(xmin, xmax))

# plot the confidence interval and the regression line of the linear model
poly <- c(preds[,2],rev(preds[,3]))
polygon(newx2,poly,col=adjustcolor("black",alpha.f=0.02), border=F)
abline(m, lty=1, col=adjustcolor("red", alpha.f=0.95))
lines(newx, preds[,3], lty= 2, col=adjustcolor("black", alpha.f=0.1))
lines(newx, preds[,2], lty= 2, col=adjustcolor("black", alpha.f=0.1))

# plot the std-dev of the curSize and tentacle values
for(i in 1:nrow(sumTentSize2)){
    Tvals <- c(sumTentSize2[i,"tentacles"] - sumTentSize2[i, "stdErrTent"],
                sumTentSize2[i,"tentacles"] + sumTentSize2[i, "stdErrTent"])
    Svals <- c(sumTentSize2[i,"curSize"] - sumTentSize2[i, "stdErrCurSize"],
                sumTentSize2[i,"curSize"] + sumTentSize2[i, "stdErrCurSize"])
    points(rep(sumTentSize2[i, "curSize"],2),Tvals, pch = 190, font=5, cex=0.5)
    points(rep(sumTentSize2[i, "curSize"],2),Tvals, type = "l",lwd=0.5)
    points(Svals,rep(sumTentSize2[i, "tentacles"],2), pch = 189, font=5, cex=0.5)
    points(Svals,rep(sumTentSize2[i, "tentacles"],2), type = "l",lwd=0.5)
}


# plot the actual points and the statistics
points(data=sumTentSize2, tentacles~curSize, bg=sumTentSize2[["cols"]], pch=sumTentSize2[["shape"]])
text(min(sumTentSize2[["curSize"]]),min(sumTentSize2[["tentacles"]])*0.97,paste("R² = ", round(summary(m)$adj.r.squared, digits=2), "\np = ", round(anova(m)[["Pr(>F)"]][1], digits=6),sep=''), pos=4, offset=-1.5)

dev.off()

# calculate and print statistics of the linear model with both factors explaining size

m <- lm(data=sumTentSize2, size~tentacles*curSize)
print(summary(m))
